<p align="center">
  <a href="https://tools.codinasion.org/" target="_blank">
    <picture>
      <source media="(prefers-color-scheme: dark)" srcset="../readme/lightTxt.png">
      <source media="(prefers-color-scheme: light)" srcset="../readme/darkTxt.png">
      <img alt="Codinasion tools" src="./src/lightTxt.png" width="350">
    </picture>
  </a>
</p>
<p align="center">
A collection of open source tools that can be used to help you in your daily activities.
</p>
<div align="center">

![LICENSE](https://img.shields.io/github/license/codinasion/codinasion-tools?color=lightgreen)
[![PIP](https://img.shields.io/pypi/v/codinasion-tools?color=lightgreen)](https://pypi.org/project/codinasion-tools "PIP Package")

</div>

<hr/>

<picture align="center">
  <source media="(prefers-color-scheme: dark)" srcset="../readme/darkBg.png">
  <source media="(prefers-color-scheme: light)" srcset="../readme/lightBg.png">
  <img alt="Codinasion tools" src="./src/lightBg.png">
</picture>

<br/>
<br/>

## Table of Contents

- [Table of Contents](#table-of-contents)
- [Documentation](#documentation)
  - [How To Install](#how-to-install)
  - [How To Use](#how-to-use)

<br/>

<div align="center">
  <img src="https://raw.githubusercontent.com/codinasion/.github/master/assets/rainbow-hr.png" alt="rainbow hr" width="100%" height="70%">
</div>

## Documentation

### How To Install

```bash
pip install codinasion-tools
```

### How To Use

```python
from codinasion_tools import ConvertDecimalToBinary

binary = ConvertDecimalToBinary(10)
print(binary) # 1010
```

<br/>

<div align="center">
  <img src="https://raw.githubusercontent.com/codinasion/.github/master/assets/rainbow-hr.png" alt="rainbow hr" width="100%" height="70%">
</div>

<br/>

<p align="center">
Made with 💖 by Codinasion
</p>

<div align="center">
  <img src="https://raw.githubusercontent.com/codinasion/.github/master/assets/rainbow-hr.png" alt="rainbow hr" width="100%" height="70%">
</div>
